@@ -127,6 +127,7 @@ class OOSheet(OODoc):
 
         Selector is case-insensitive
         """
+
         if not selector:
             return
         
@@ -379,6 +380,16 @@ class OOSheet(OODoc):
         self.end_col += num
         return self
 
+    def flatten(self):
+        """Keeps the value and string of cells in selection, but make them independent of a formula."""
+        for cell in self.cells:
+            if cell.getValue():
+                cell.setValue(cell.getValue())
+            elif cell.getString():
+                cell.setString(cell.getString())
+            
+        return self
+
     @property
     def first_row(self):
         return self.clone().shrink_down(self.height - 1)
@@ -697,6 +708,34 @@ class OOSheet(OODoc):
         """
         return OOSheet(self.selector)
 
+    def protect_sheet(self, password = ""):
+        """Protects selection's sheet against editions. When sheet is protected, only unprotected
+        cells can be modified.
+        Password ensures sheet can only be unprotected with same password.
+        """
+        self.sheet.protect(password)
+        return self
+
+    def unprotect_sheet(self, password = ""):
+        """Unprotects selection's sheet against editions. When sheet is unprotected, all cells
+        can be modified.
+        Needs password if sheet has been protected with password.
+        """
+        self.sheet.unprotect(password)
+        return self
+
+    def protect(self):
+        """Protects selection's cells against edition. Only in effect when sheet is protected"""
+        self.focus()
+        self.dispatch('.uno:Protection', ('Protection.Locked', True))
+        return self
+    
+    def unprotect(self):
+        """Unprotects selections's cell against edition."""
+        self.focus()
+        self.dispatch('.uno:Protection', ('Protection.Locked', False))
+        return self
+    
     def quit(self):
         """Closes the OpenOffice.org instance"""
         self.dispatch('.uno:Quit')
